@@ -4,12 +4,7 @@ import numpy as np
 
 
 class BaseModel(ABC):
-    def __init__(self,
-                 num_features,
-                 reg_lambda,
-                 use_linear,
-                 sigmoid,
-                 regression):
+    def __init__(self, num_features, reg_lambda, use_linear, sigmoid, regression):
         self.sigmoid = sigmoid
         self.regression = regression
 
