@@ -6,12 +6,16 @@ from pyffm.engine.ffm_engine import FFMEngine
 
 class TestEngine(unittest.TestCase):
     def setUp(self) -> None:
-        self.ctr_engine = FFMEngine(training_params={'epochs': 10, 'parallel': False})
+        self.ctr_engine = FFMEngine(training_params={"epochs": 10, "parallel": False})
 
     def test_basic_train(self):
-        x_data = np.array([[(0, 0, 1), (1, 1, 1), (2, 2, 1), (3, 3, 1)],
-                           [(0, 4, 1), (1, 5, 1), (2, 2, 1), (3, 3, 1)],
-                           [(0, 6, 1), (1, 7, 1), (2, 8, 1), (3, 9, 1)]])
+        x_data = np.array(
+            [
+                [(0, 0, 1), (1, 1, 1), (2, 2, 1), (3, 3, 1)],
+                [(0, 4, 1), (1, 5, 1), (2, 2, 1), (3, 3, 1)],
+                [(0, 6, 1), (1, 7, 1), (2, 8, 1), (3, 9, 1)],
+            ]
+        )
         y_data = np.array([0, 1, 0])
         self.ctr_engine.train(x_data, y_data)
 
